#-----------------------------------------------------------------------
# File    : hamster.mak
# Contents: commands to build hamster program
# Author  : Christian Borgelt
# History : 2003.01.29 file created
#           2006.07.20 adapted to Visual Studio 8
#           2016.04.20 completed dependencies on header files
#-----------------------------------------------------------------------
CC       = cl.exe
RSC      = rc.exe
LD       = link.exe
DEFS     = /D WIN32 /D NDEBUG /D _CRT_SECURE_NO_DEPRECATE
CFLAGS   = /nologo /W3 /O2 $(DEFS) /c /Fdbin\\ /Fpbin\\
RFLAGS   = /l 0x407 /d NDEBUG
LDFLAGS  = /nologo /incremental:no
LIBS     = user32.lib comdlg32.lib gdi32.lib
INC      = /I .\windows /I .\common

THISDIR  = ..\..\hamster\src
HDRS     = common\maze.h common\server.h common\hamster.h
OBJS     = bin\maze.obj bin\server.obj
WINOBJS  = bin\sprite.obj bin\whamster.obj bin\whamster.res
PRGS     = bin\whamster.exe bin\chamster.exe

#-----------------------------------------------------------------------
# Build Programs
#-----------------------------------------------------------------------
all:        $(PRGS)

bin\whamster.exe: $(OBJS) $(WINOBJS) hamster.mak
	$(LD) $(LDFLAGS) $(OBJS) $(WINOBJS) $(LIBS) \
        /subsystem:windows /out:$@

bin\chamster.exe: bin\client.obj bin\control.obj hamster.mak
	$(LD) $(LDFLAGS) bin\client.obj bin\control.obj $(LIBS) \
        /subsystem:console /out:$@

#-----------------------------------------------------------------------
# Build Windows Modules
#-----------------------------------------------------------------------
bin\whamster.obj: $(HDRS)
bin\whamster.obj: windows\whamster.c windows\whamster.rh hamster.mak
	$(CC) $(CFLAGS) $(INC) windows\whamster.c /D _WINDOWS /Fo$@

bin\sprite.obj:   windows\sprite.c windows\sprite.h hamster.mak
	$(CC) $(CFLAGS) $(INC) windows\sprite.c /D _WINDOWS /Fo$@

#-----------------------------------------------------------------------
# Build OS Independent Modules
#-----------------------------------------------------------------------
bin\maze.obj:     common\maze.h common\maze.c hamster.mak
	$(CC) $(CFLAGS) $(INC) common\maze.c /Fo$@

bin\server.obj:   $(HDRS)
bin\server.obj:   common\server.c $(HDRS) makefile
	$(CC) $(CFLAGS) $(INC) common\server.c /Fo$@

bin\client.obj:   common\hamster.h
bin\client.obj:   common\client.c makefile
	$(CC) $(CFLAGS) $(INC) common\client.c /Fo$@

bin\control.obj:  common\hamster.h
bin\control.obj:  common\control.c makefile
	$(CC) $(CFLAGS) $(INC) common\control.c /Fo$@

#-----------------------------------------------------------------------
# Resources
#-----------------------------------------------------------------------
bin\whamster.res: windows\whamster.rh windows\whamster.rc hamster.mak
	$(RSC) $(RFLAGS) /fo$@ windows\whamster.rc

#-----------------------------------------------------------------------
# Clean up
#-----------------------------------------------------------------------
clean:
	-@erase /Q *~ bin\*

localclean:
	-@erase /Q *~ bin\*
